import { useState, useEffect } from 'react';
import { Link, useNavigate } from 'react-router-dom';
import getBooks from '../../../utils/getBooks';

import IconSearch from '../../ui/Icon/IconSearch';

import styles from './AutoComplete.module.css';

const AutoComplete = () => {
  let navigate = useNavigate();
  const [books, setBooks] = useState([]);
  const [query, setQuery] = useState('');
  const [showSuggestions, setShowSuggestions] = useState(false);

  useEffect(() => {
    if (query.length > 3) {
      getBooks({ query: query, maxResults: '6' }).then((books) => {
        setBooks(books.items);
      });
    }
  }, [query]);

  const handleSubmit = (e) => {
    e.preventDefault();
    setShowSuggestions(false);

    if (query.length >= 3) navigate(`/libros?q=${query}`);
  };

  const handleChange = (e) => {
    setShowSuggestions(true);
    setQuery(e.target.value);
  };

  const handleKeyDown = (e) => {
    // Enter key
    if (e.keyCode === 13) {
      setShowSuggestions(false);
    }

    // Escape key
    else if (e.keyCode === 27) {
      setShowSuggestions(false);
    }
  };

  return (
    <form onSubmit={handleSubmit} className={styles.form}>
      <label htmlFor="search">
        <input
          id="search"
          type="text"
          placeholder="Busca por título, autor o ISBN..."
          className={styles.input}
          value={query}
          onChange={handleChange}
          onKeyDown={handleKeyDown}
        />

        <button type="submit">
          <IconSearch />
        </button>
      </label>

      {showSuggestions && query.length > 3 && books.length ? (
        <ul className={styles.list}>
          {books
            .filter((suggestion) =>
              suggestion.volumeInfo.title
                .toLowerCase()
                .includes(query.toLowerCase())
            )
            .map((suggestion) => {
              return (
                <li key={suggestion.id}>
                  <Link to={`/libro/${suggestion.id}`} reloadDocument>
                    {suggestion.volumeInfo.title}
                  </Link>
                </li>
              );
            })}
        </ul>
      ) : null}
    </form>
  );
};

export default AutoComplete;
