import { Link } from 'react-router-dom';
import _ from 'lodash';

import Favorite from '../../Favorite/Favorite';
import IconStar from '../../../ui/Icon/IconStar';
import IconStarAverage from '../../../ui/Icon/IconStarAverage';
import Share from '../../Share/Share';

import styles from './BookDetail.module.css';

const BookDetail = ({ bookId, book }) => {
  const bookUrl = window.location;
  let numberOfStars = book.averageRating;

  return (
    <article>
      <h1 className={styles.title}>{book.title}</h1>

      <section className={styles.information}>
        <div>
          <div className={styles.image}>
            {book.imageLinks && (
              <img src={book.imageLinks.thumbnail} alt={book.title} />
            )}
          </div>

          <Favorite bookId={bookId} large={true} />
        </div>

        <div>
          <ul>
            <li>
              <span>Autor</span>
              {book.authors && book.authors[0]}
            </li>
            <li>
              <span>Editor</span>
              {book.publisher && `${book.publisher}, ${book.publishedDate}`}
            </li>
            <li>
              <span>ISBN</span>
              {book.industryIdentifiers && book.industryIdentifiers[0].identifier}
            </li>
            <li>
              <span>N° de páginas</span>
              {book.pageCount && book.pageCount}
            </li>
            <li>
              <span>Preview link</span>
              {book.previewLink && (
                <a href={book.previewLink} target="_blank" rel="noreferrer">Google Books</a>
              )}
            </li>
          </ul>

          <div className={styles.stars}>
            <div className={styles.starsAverage}>
              {_.times(numberOfStars, (i) => (
                <IconStar key={i} />
              ))}
            </div>

            <IconStarAverage />
          </div>

          <a href={`https://books.google.ch/books?id=${bookId}&hl=es&sitesec=reviews`} className={styles.numberReviews}>
            {book.ratingsCount ? book.ratingsCount : 0} Reseña(s)
          </a>
        </div>
      </section>

      {book.description && (
        <section className={styles.description}>
          <h2 className={styles.subtitle}>Descripción</h2>
          <div dangerouslySetInnerHTML={{ __html: book.description }}></div>
        </section>
      )}

      {book.categories && (
        <section className={styles.categories}>
          <h2 className={styles.subtitle}>Categorías</h2>
          <ul>
            {book.categories.map((category) => (
              <li key={category}><Link to={`/libros?q=subject:${category}`}>{category}</Link></li>
            ))}
          </ul>
        </section>
      )}

      <section className={styles.share}>
        <h2 className={styles.subtitle}>Compartir</h2>
        <Share url={bookUrl} />
      </section>
    </article>
  );
};

export default BookDetail;
