import { useState, useEffect } from 'react';
import { useAuth } from '../../../context/AuthContext';
import favoritesServices from '../../../utils/favoritesServices';
import ReactTooltip from 'react-tooltip';

import IconHeart from '../../ui/Icon/IconHeart';

import styles from './Favorite.module.css';

const Favorite = ({ bookId, large = false }) => {
  const { currentUser } = useAuth();
  const [favorite, setFavorite] = useState(false);

  const handleAddFavorite = async () => {
    setFavorite(true);
    await favoritesServices.addFavorite(bookId, currentUser.uid);
  };

  const handleRemoveFavorite = async () => {
    setFavorite(false);
    await favoritesServices.deleteFavorite(bookId, currentUser.uid);
  };

  useEffect(() => {
    const isFavorite = async () => {
      const getFavorite = await favoritesServices.getFavorite(bookId, currentUser.uid);
      if (getFavorite.length > 0) setFavorite(true);
    };

    if (currentUser) {
      return isFavorite();
    }
  }, [bookId, currentUser]);

  if (!currentUser) {
    return (
      <div className={`${styles.favoriteBtn} ${large === true && styles.favoriteBtnLarge}`}>
        <button data-tip="Registrate para guardar un libro en tus favoritos">
          <IconHeart />
        </button>

        {large === true && 'Guardar en favoritos'}

        <ReactTooltip
          className={styles.favoriteTooltip}
          backgroundColor="#f4f1ea"
          place="top"
          effect="solid"
          delayHide={100}
        />
      </div>
    );
  }

  return (
    <div className={`${styles.favoriteBtn} ${large === true && styles.favoriteBtnLarge}`}>
      {favorite === false ? (
        <>
          <button onClick={handleAddFavorite}>
            <IconHeart />
          </button>
          {large === true && 'Guardar en favoritos'}
        </>
      ) : (
        <>
          <button onClick={handleRemoveFavorite}>
            <IconHeart fill={true} />
          </button>
          {large === true && 'Eliminar de favoritos'}
        </>
      )}
    </div>
  );
};

export default Favorite;
