import { useState } from 'react';
import { Link, useNavigate } from 'react-router-dom';
import { useAuth } from '../../../../context/AuthContext';
import authTranslations from '../../../../translations/authTranslations';

import Alert from '../../../ui/Alert/Alert';

import styles from './LoginForm.module.css';

const LoginForm = () => {
  const navigate = useNavigate();
  const { login } = useAuth();
  const [email, setEmail] = useState('');
  const [password, setPassword] = useState('');
  const [error, setError] = useState('');

  // Change handlers
  const emailChangeHandler = (e) => {
    setEmail(e.target.value);
  };

  const passwordChangeHandler = (e) => {
    setPassword(e.target.value);
  };

  // Submit handler
  const handleSubmit = async (e) => {
    e.preventDefault();

    try {
      await login(email, password);
      navigate('/dashboard');
    } catch (err) {
      setError(authTranslations[err.code] || err.message);
    }
  };

  return (
    <>
      <Alert message={error} type="error" />

      <form onSubmit={handleSubmit}>
        <label htmlFor="email">
          Email:
          <input id="email" type="email" onChange={emailChangeHandler} />
        </label>

        <label htmlFor="password">
          Contraseña:
          <input
            id="password"
            type="password"
            onChange={passwordChangeHandler}
          />
        </label>

        <button type="submit">Login</button>
      </form>

      <div className={styles.loginInfo}>
        <p>¿Necesitas una cuenta? <Link to="/registro">Registro</Link></p>
        <p>¿Olvidaste tu contraseña? <Link to="/restablecer-password">Restablecer</Link></p>
      </div>
    </>
  );
};

export default LoginForm;
