import { useState } from 'react';
import { Link, useNavigate } from 'react-router-dom';
import { useAuth } from '../../../../context/AuthContext';
import authTranslations from '../../../../translations/authTranslations';

import Alert from '../../../ui/Alert/Alert';

import styles from './RegisterForm.module.css';

const RegisterForm = () => {
  const navigate = useNavigate();
  const { register } = useAuth();
  const [name, setName] = useState('');
  const [email, setEmail] = useState('');
  const [password, setPassword] = useState('');
  const [error, setError] = useState('');

  // Change handlers
  const nameChangeHandler = (e) => {
    setName(e.target.value);
  };

  const emailChangeHandler = (e) => {
    setEmail(e.target.value);
  };

  const passwordChangeHandler = (e) => {
    setPassword(e.target.value);
  };

  // Submit handler
  const handleSubmit = async (e) => {
    e.preventDefault();

    try {
      await register(name, email, password);
      navigate('/dashboard');
    } catch (err) {
      setError(authTranslations[err.code] || err.message);
    }
  };

  return (
    <>
      <Alert message={error} type="error" />

      <form onSubmit={handleSubmit}>
        <label htmlFor="name">
          Nombre:
          <input id="name" type="text" onChange={nameChangeHandler} />
        </label>

        <label htmlFor="email">
          Email:
          <input id="email" type="email" onChange={emailChangeHandler} />
        </label>

        <label htmlFor="password">
          Contraseña:
          <input
            id="password"
            type="password"
            onChange={passwordChangeHandler}
          />
        </label>

        <button type="submit">Registro</button>
      </form>

      <div className={styles.registerInfo}>
        ¿Ya tienes una cuenta? <Link to="/login">Log In</Link>
      </div>
    </>
  );
};

export default RegisterForm;
