import { useState } from 'react';
import { useNavigate } from 'react-router-dom';
import { useAuth } from '../../../../context/AuthContext';
import authTranslations from '../../../../translations/authTranslations';

import Alert from '../../../ui/Alert/Alert';

const ResetPasswordForm = () => {
  const navigate = useNavigate();
  const { resetPassword } = useAuth();
  const [email, setEmail] = useState('');
  const [error, setError] = useState('');
  const [errorType, setErrorType] = useState('error');

  // Change handlers
  const emailChangeHandler = (e) => {
    setEmail(e.target.value);
  };

  // Submit handler
  const handleSubmit = async (e) => {
    e.preventDefault();

    try {
      await resetPassword(email);
      setErrorType('success');
      setError('Porfavor revisa tu correo para restablecer la contraseña.');

      setTimeout(() => {
        navigate('/login');
      }, 2000);
    } catch (err) {
      setErrorType('error');
      setError(authTranslations[err.code] || err.message);
    }
  };

  return (
    <>
      <Alert message={error} type={errorType} />

      <form onSubmit={handleSubmit}>
        <label htmlFor="email">
          Email:
          <input id="email" type="email" onChange={emailChangeHandler} />
        </label>

        <button type="submit">Restablecer</button>
      </form>
    </>
  );
};

export default ResetPasswordForm;
