import { useState, useEffect, useRef } from 'react';
import { NavLink, Link } from 'react-router-dom';
import { useNavigate } from 'react-router-dom';
import { useAuth } from '../../../context/AuthContext';

import Logo from '../../ui/Logo/Logo';
import AutoComplete from '../AutoComplete/AutoComplete';
import HeaderDropdown from '../HeaderDropdown/HeaderDropdown';
import IconChevron from '../../ui/Icon/IconChevron';

import styles from './Header.module.css';

const Header = () => {
  const navigate = useNavigate();
  const { currentUser, logout } = useAuth();
  const [dropdown, setDropdown] = useState(false);
  let ref = useRef();

  const handleLogout = async () => {
    try {
      await logout();
      navigate('/');
    } catch (err) {
      console.log('error', err.message);
    }
  };

  const isLibrosPageActive = () => {
    if (window.location.pathname === '/libros') {
      return styles.isActive;
    }
  }

  useEffect(() => {
    const handler = (event) => {
      if (dropdown && ref.current && !ref.current.contains(event.target)) {
        setDropdown(false);
      }
    };
    document.addEventListener('mousedown', handler);
    document.addEventListener('touchstart', handler);
    return () => {
      // Cleanup the event listener
      document.removeEventListener('mousedown', handler);
      document.removeEventListener('touchstart', handler);
    };
  }, [dropdown]);

  return (
    <header className={styles.header}>
      <div className={styles.headerWrapper}>
        <div className={styles.headerLeft}>
          <Link to="/" className={styles.logo}>
            <Logo />
          </Link>

          <AutoComplete />
        </div>

        <nav className={styles.headerRight}>
          <ul>
            <li><NavLink to="/" className={(navData) => (navData.isActive && styles.isActive)}>Inicio</NavLink></li>
            <li className={styles.linkDropdown} ref={ref}>
              <button aria-expanded={dropdown ? 'true' : 'false'} onClick={() => setDropdown((prev) => !prev)} className={isLibrosPageActive()}>
                Libros
                <IconChevron />
              </button>

              {dropdown && <HeaderDropdown />}
            </li>

            {currentUser?.email ? (
              <>
                <li><NavLink to="/dashboard" className={(navData) => (navData.isActive && styles.isActive)}>Perfil</NavLink></li>
                <button onClick={handleLogout} className="secondary">Logout</button>
              </>
            ) : (
              <>
                <li><NavLink to="/login" className={(navData) => (navData.isActive && styles.isActive)}>Login</NavLink></li>
                <li><NavLink to="/registro" className={(navData) => (navData.isActive && styles.isActive)}>Registro</NavLink></li>
              </>
            )}
          </ul>
        </nav>
      </div>
    </header>
  );
};

export default Header;
