import { useState, useEffect } from 'react';
import { useAuth } from '../../../../context/AuthContext';
import favoritesServices from '../../../../utils/favoritesServices';

import BookCard from '../../Book/BookCard/BookCard';

import styles from './UserFavorites.module.css';

const UserFavorites = () => {
  const { currentUser } = useAuth();
  const [favorites, setFavorites] = useState([]);
  const [book, setBook] = useState([]);

  const getSingleBook = ({ id }) => {
    const apiURL = `https://www.googleapis.com/books/v1/volumes/${id}`;

    return fetch(apiURL)
      .then((res) => res.json())
      .then((result) => {
        if (result) {

          const book = {
            id: result.id,
            title: result.volumeInfo.title,
            authors: result.volumeInfo.authors,
            imageUrl: result.volumeInfo.imageLinks,
          };

          return book;
        }
      });
  };

  useEffect(() => {
    const userFavorites = async () => {
      const favoritesList = await favoritesServices.getAllFavorites(currentUser.uid);
      if (favoritesList.length > 0) setFavorites(favoritesList);
    };

    return userFavorites();
  }, [currentUser.uid]);

  useEffect(() => {
    if (favorites.length > 0) {
      favorites.forEach((favorite) => {
        getSingleBook({ id: favorite }).then((newBook) => {
          setBook((prevBook) => [...prevBook, newBook]);
        });
      });
    }
  }, [favorites]);

  return (
    <section className={styles.wrapper}>
      <h3>Libros favoritos</h3>
      <ul className={styles.list}>
        {book.length > 0 &&
          book.map((item) => (
            <li key={item.id}>
              <BookCard
                id={item.id}
                title={item.title}
                imageUrl={item.imageUrl}
                authors={item.authors}
              />
            </li>
          ))}
      </ul>

      {book.length === 0 && <p>No tienes libros favoritos.</p>}
    </section>
  );
};

export default UserFavorites;
