import { useState, useEffect } from 'react';
import ReactPaginate from 'react-paginate';
import { useLocation } from 'react-router-dom';
import getBooks from '../../utils/getBooks';

import MainLayout from '../../components/layout/MainLayout/MainLayout';
import Title from '../../components/ui/Title/Title';
import BookSearch from '../../components/layout/Book/BookSearch/BookSearch';

import styles from './/BrowsePage.module.css';

const BrowsePage = () => {
  const search = useLocation().search;
  const query = new URLSearchParams(search).get('q');
  const [books, setBooks] = useState(null);
  const [perPage] = useState(10);
  const [offset, setOffset] = useState(0);
  const [pageCount, setPageCount] = useState(0);
  const [totalItems, setTotalItems] = useState(0);

  useEffect(() => {
    getBooks({ query: query }).then((books) => {
      setTotalItems(books.totalItems);
    });
  }, [query]);

  useEffect(() => {
    getBooks({ query: query, maxResults: perPage, startIndex: offset }).then(
      (books) => {
        setBooks(books.items);
        const pageCount = Math.ceil(books.totalItems / perPage);

        if (pageCount > 20) {
          setPageCount(20);
        } else {
          setPageCount(Math.ceil(totalItems / perPage));
        }
      }
    );
  }, [query, offset, perPage, totalItems]);

  const handlePageClick = (e) => {
    const newOffset = (e.selected * perPage) % totalItems;
    setOffset(newOffset);
  };

  return (
    <MainLayout>
      {query ? (
        <>
          <Title text="Busca un" highlightText="libro" />
          Búsqueda: {query.replace('subject:', '')}
        </>
      ) : (
        <Title text="Busca un" highlightText="libro" />
      )}

      {query && books && books.length ? (
        <>
          <ul className={styles.list}>
            {books &&
              books.length &&
              books.map((item) => {
                return (
                  <li key={item.id}>
                    <BookSearch
                      id={item.id}
                      title={item.volumeInfo.title}
                      imageUrl={item.volumeInfo.imageLinks}
                      authors={item.volumeInfo.authors}
                      description={item.volumeInfo.description}
                    />
                  </li>
                );
              })}
          </ul>

          {totalItems > perPage && (
            <ReactPaginate
              breakLabel="..."
              nextLabel="Siguiente"
              onPageChange={handlePageClick}
              marginPagesDisplayed={1}
              pageRangeDisplayed={2}
              pageCount={pageCount}
              previousLabel="Anterior"
              renderOnZeroPageCount={null}
              containerClassName={'pagination'}
              activeClassName={'active'}
            />
          )}
        </>
      ) : null}

      {/* {query && !books && (
        <>
          <p>No existen resultados:</p>
          <ul>
            <li>Busca por título y autor</li>
            <li>Intenta buscar por ISBN</li>
            <li>Verifica la ortografía</li>
          </ul>
        </>
      )} */}
    </MainLayout>
  );
};

export default BrowsePage;
