import { useState, useEffect } from 'react';
import { useAuth } from '../../context/AuthContext';
import { query, collection, getDocs, where } from 'firebase/firestore';
import { db } from '../../firebase/firebaseConfig';

import MainLayout from '../../components/layout/MainLayout/MainLayout';
import UserData from '../../components/layout/User/UserData/UserData';
import UserActions from '../../components/layout/User/UserActions/UserActions';
import UserFavorites from '../../components/layout/User/UserFavorites/UserFavorites';

import styles from './DashboardPage.module.css';

const DashboardPage = () => {
  const { currentUser } = useAuth();
  const [userData, setUserData] = useState('');

  useEffect(() => {
    const fetchUserData = async () => {
      const q = query(
        collection(db, 'users'),
        where('uid', '==', currentUser?.uid)
      );
      const doc = await getDocs(q);
      const data = doc.docs[0].data();

      setUserData(data);
    };

    if (currentUser) fetchUserData();
  }, [currentUser]);

  return (
    <MainLayout>
      <>
        <div className={styles.userData}>
          <UserData user={userData} />
          <UserActions />
        </div>

        <UserFavorites />
      </>
    </MainLayout>
  );
};

export default DashboardPage;
